Nope. "standard" AJAX frameworks and widget sets are written in javascript, a low-level alien language with weird complexities that is often confused with not only the browsers it runs on but also the DOM model set of functions that are provided as standard with the browsers. When you use a "standard" AJAX framework, there is an expectation that you will just "use" it - never look at the framework, never get involved with its development or improvement, and if that AJAX framework doesn't do what you want, tough luck - find another one.

Pyjamas is a totally different approach: it brings "Declarative Programming" (in python) to the Web. You are given a comprehensive set of base classes and modules - written almost 98.5% in python - and you can then write your own applications, classes and modules and call it "My Own AJAX Framework". And, as you are writing in a much higher level language than Javascript, it's a darn sight easier.